Type Definition xcm::AlwaysRelease [−][src]
pub type AlwaysRelease = AlwaysV0;Expand description
WrapVersion implementation which attempts to always convert the XCM to the release version before wrapping it.
pub type AlwaysRelease = AlwaysV0;WrapVersion implementation which attempts to always convert the XCM to the release version before wrapping it.