Enum xcm::v0::Order [−][src]
pub enum Order<Call> {
Null,
DepositAsset {
assets: Vec<MultiAsset>,
dest: MultiLocation,
},
DepositReserveAsset {
assets: Vec<MultiAsset>,
dest: MultiLocation,
effects: Vec<Order<()>>,
},
ExchangeAsset {
give: Vec<MultiAsset>,
receive: Vec<MultiAsset>,
},
InitiateReserveWithdraw {
assets: Vec<MultiAsset>,
reserve: MultiLocation,
effects: Vec<Order<()>>,
},
InitiateTeleport {
assets: Vec<MultiAsset>,
dest: MultiLocation,
effects: Vec<Order<()>>,
},
QueryHolding {
query_id: u64,
dest: MultiLocation,
assets: Vec<MultiAsset>,
},
BuyExecution {
fees: MultiAsset,
weight: u64,
debt: u64,
halt_on_error: bool,
xcm: Vec<Xcm<Call>>,
},
}Expand description
An instruction to be executed on some or all of the assets in holding, used by asset-related XCM messages.
Variants
Do nothing. Not generally used.
Remove the asset(s) (assets) from holding and place equivalent assets under the ownership of dest within
this consensus system.
assets: The asset(s) to remove from holding.dest: The new owner for the assets.
Errors:
Fields of DepositAsset
assets: Vec<MultiAsset>dest: MultiLocationRemove the asset(s) (assets) from holding and place equivalent assets under the ownership of dest within
this consensus system.
Send an onward XCM message to dest of ReserveAssetDeposit with the given effects.
assets: The asset(s) to remove from holding.dest: The new owner for the assets.effects: The orders that should be contained in theReserveAssetDepositwhich is sent onwards todest.
Errors:
Fields of DepositReserveAsset
Remove the asset(s) (give) from holding and replace them with alternative assets.
The minimum amount of assets to be received into holding for the order not to fail may be stated.
give: The asset(s) to remove from holding.receive: The minimum amount of assets(s) whichgiveshould be exchanged for. The meaning of wildcards is undefined and they should be not be used.
Errors:
Fields of ExchangeAsset
give: Vec<MultiAsset>receive: Vec<MultiAsset>Remove the asset(s) (assets) from holding and send a WithdrawAsset XCM message to a reserve location.
assets: The asset(s) to remove from holding.reserve: A valid location that acts as a reserve for all asset(s) inassets. The sovereign account of this consensus system on the reserve location will have appropriate assets withdrawn andeffectswill be executed on them. There will typically be only one valid location on any given asset/chain combination.effects: The orders to execute on the assets once withdrawn on the reserve location.
Errors:
Fields of InitiateReserveWithdraw
Remove the asset(s) (assets) from holding and send a TeleportAsset XCM message to a destination location.
assets: The asset(s) to remove from holding.destination: A valid location that has a bi-lateral teleportation arrangement.effects: The orders to execute on the assets once arrived on the destination location.
Errors:
Fields of InitiateTeleport
Send a Balances XCM message with the assets value equal to the holding contents, or a portion thereof.
query_id: An identifier that will be replicated into the returned XCM message.dest: A valid destination for the returned XCM message. This may be limited to the current origin.assets: A filter for the assets that should be reported back. The assets reported back will be, asset- wise, the lesser of this value and the holding account. No wildcards will be used when reporting assets back.
Errors:
Fields of QueryHolding
Pay for the execution of some XCM with up to weight picoseconds of execution time, paying for this with
up to fees from the holding account.
Errors:
Implementations