Struct xcm::v1::prelude::MultiAssets [−][src]
pub struct MultiAssets(_);Expand description
A Vec of MultiAssets. There may be no duplicate fungible items in here and when decoding, they must be sorted.
Implementations
Create a new instance of MultiAssets from a Vec<MultiAsset> whose contents are sorted and
which contain no duplicates.
Returns Ok if the operation succeeds and Err if r is out of order or had duplicates. If you can’t
guarantee that r is sorted and deduplicated, then use From::<Vec<MultiAsset>>::from which is infallible.
Create a new instance of MultiAssets from a Vec<MultiAsset> whose contents are sorted and
which contain no duplicates.
In release mode, this skips any checks to ensure that r is correct, making it a negligible-cost operation.
Generally though you should avoid using it unless you have a strict proof that r is valid.
In test mode, this checks anyway and panics on fail.
Add some asset onto the list, saturating. This is quite a laborious operation since it maintains the ordering.
Returns true if self is a super-set of the given inner.
Consume self and return the inner vec.
Return a reference to the inner vec.
Prepend a MultiLocation to any concrete asset items, giving it a new root location.
Return a reference to an item at a specific index or None if it doesn’t exist.