Enum xcm::v2::Error [−][src]
pub enum Error {
Show 26 variants
Overflow,
Unimplemented,
UntrustedReserveLocation,
UntrustedTeleportLocation,
MultiLocationFull,
MultiLocationNotInvertible,
BadOrigin,
InvalidLocation,
AssetNotFound,
FailedToTransactAsset(&'static str),
NotWithdrawable,
LocationCannotHold,
ExceedsMaxMessageSize,
DestinationUnsupported,
Transport(&'static str),
Unroutable,
UnknownClaim,
FailedToDecode,
TooMuchWeightRequired,
NotHoldingFees,
TooExpensive,
Trap(u64),
UnhandledXcmVersion,
WeightLimitReached(Weight),
Barrier,
WeightNotComputable,
}Variants
An arithmetic overflow happened.
The instruction is intentionally unsupported.
Origin Register does not contain a value value for a reserve transfer notification.
Origin Register does not contain a value value for a teleport notification.
MultiLocation value too large to descend further.
MultiLocation value ascend more parents than known ancestors of local location.
The Origin Register does not contain a valid value for instruction.
The location parameter is not a valid value for the instruction.
The given asset is not handled.
FailedToTransactAsset(&'static str)An asset transaction (like withdraw or deposit) failed (typically due to type conversions).
Tuple Fields of FailedToTransactAsset
0: &'static strAn asset cannot be withdrawn, potentially due to lack of ownership, availability or rights.
An asset cannot be deposited under the ownership of a particular location.
Attempt to send a message greater than the maximum supported by the transport protocol.
The given message cannot be translated into a format supported by the destination.
Transport(&'static str)Destination is routable, but there is some issue with the transport mechanism.
Tuple Fields of Transport
0: &'static strDestination is known to be unroutable.
Used by ClaimAsset when the given claim could not be recognized/found.
Used by Transact when the functor cannot be decoded.
Used by Transact to indicate that the given weight limit could be breached by the functor.
Used by BuyExecution when the Holding Register does not contain payable fees.
Used by BuyExecution when the fees declared to purchase weight are insufficient.
Trap(u64)Used by the Trap instruction to force an error intentionally. Its code is included.
Tuple Fields of Trap
0: u64XCM version not able to be handled.
WeightLimitReached(Weight)Execution of the XCM would potentially result in a greater weight used than weight limit.
Tuple Fields of WeightLimitReached
0: WeightThe XCM did not pass the barrier condition for execution.
The barrier condition differs on different chains and in different circumstances, but generally it means that the conditions surrounding the message were not such that the chain considers the message worth spending time executing. Since most chains lift the barrier to execution on appropriate payment, presentation of an NFT voucher, or based on the message origin, it means that none of those were the case.
The weight of an XCM message is not computable ahead of execution.