Type Definition xcm::v2::opaque::Xcm [−][src]
pub type Xcm = Xcm<()>;Expand description
The basic concrete type of Xcm, which doesn’t make any assumptions about the
format of a call other than it is pre-encoded.
pub type Xcm = Xcm<()>;The basic concrete type of Xcm, which doesn’t make any assumptions about the
format of a call other than it is pre-encoded.