Enum xcm::v2::prelude::opaque::Junction [−][src]
pub enum Junction {
Parachain(u32),
AccountId32 {
network: NetworkId,
id: [u8; 32],
},
AccountIndex64 {
network: NetworkId,
index: u64,
},
AccountKey20 {
network: NetworkId,
key: [u8; 20],
},
PalletInstance(u8),
GeneralIndex(u128),
GeneralKey(Vec<u8>),
OnlyChild,
Plurality {
id: BodyId,
part: BodyPart,
},
}Expand description
A single item in a path to describe the relative location of a consensus system.
Each item assumes a pre-existing location as its context and is defined in terms of it.
Variants
Parachain(u32)An indexed parachain belonging to and operated by the context.
Generally used when the context is a Polkadot Relay-chain.
Tuple Fields of Parachain
0: u32A 32-byte identifier for an account of a specific network that is respected as a sovereign endpoint within the context.
Generally used when the context is a Substrate-based chain.
An 8-byte index for an account of a specific network that is respected as a sovereign endpoint within the context.
May be used when the context is a Frame-based chain and includes e.g. an indices pallet.
A 20-byte identifier for an account of a specific network that is respected as a sovereign endpoint within the context.
May be used when the context is an Ethereum or Bitcoin chain or smart-contract.
PalletInstance(u8)An instanced, indexed pallet that forms a constituent part of the context.
Generally used when the context is a Frame-based chain.
Tuple Fields of PalletInstance
0: u8GeneralIndex(u128)A non-descript index within the context location.
Usage will vary widely owing to its generality.
NOTE: Try to avoid using this and instead use a more specific item.
Tuple Fields of GeneralIndex
0: u128A nondescript datum acting as a key within the context location.
Usage will vary widely owing to its generality.
NOTE: Try to avoid using this and instead use a more specific item.
The unambiguous child.
Not currently used except as a fallback when deriving ancestry.
A pluralistic body existing within consensus.
Typical to be used to represent a governance origin of a chain, but could in principle be used to represent things such as multisigs also.
Implementations
Convert self into a MultiLocation containing 0 parents.
Similar to Into::into, except that this method can be used in a const evaluation context.
Convert self into a MultiLocation containing n parents.
Similar to Self::into, with the added ability to specify the number of parent junctions.