Enum xcm::v2::prelude::opaque::Junctions [−][src]
pub enum Junctions {
Here,
X1(Junction),
X2(Junction, Junction),
X3(Junction, Junction, Junction),
X4(Junction, Junction, Junction, Junction),
X5(Junction, Junction, Junction, Junction, Junction),
X6(Junction, Junction, Junction, Junction, Junction, Junction),
X7(Junction, Junction, Junction, Junction, Junction, Junction, Junction),
X8(Junction, Junction, Junction, Junction, Junction, Junction, Junction, Junction),
}Expand description
Non-parent junctions that can be constructed, up to the length of 8. This specific Junctions
implementation uses a Rust enum in order to make pattern matching easier.
Parent junctions cannot be constructed with this type. Refer to MultiLocation for
instructions on constructing parent junctions.
Variants
The interpreting consensus system.
X1(Junction)A relative path comprising 1 junction.
Tuple Fields of X1
0: JunctionA relative path comprising 2 junctions.
A relative path comprising 3 junctions.
A relative path comprising 4 junctions.
A relative path comprising 5 junctions.
A relative path comprising 6 junctions.
A relative path comprising 7 junctions.
A relative path comprising 8 junctions.
Tuple Fields of X8
Implementations
Convert self into a MultiLocation containing 0 parents.
Similar to Into::into, except that this method can be used in a const evaluation context.
Convert self into a MultiLocation containing n parents.
Similar to Self::into, with the added ability to specify the number of parent junctions.
Returns first junction, or None if the location is empty.
Returns last junction, or None if the location is empty.
Splits off the first junction, returning the remaining suffix (first item in tuple) and the first element
(second item in tuple) or None if it was empty.
Splits off the last junction, returning the remaining prefix (first item in tuple) and the last element
(second item in tuple) or None if it was empty.
Removes the first element from self, returning it (or None if it was empty).
Removes the last element from self, returning it (or None if it was empty).
Mutates self to be appended with new or returns an Err with new if would overflow.
Mutates self to be prepended with new or returns an Err with new if would overflow.
Consumes self and returns a Junctions suffixed with new, or an Err with the
original value of self and new in case of overflow.
Consumes self and returns a Junctions prefixed with new, or an Err with the
original value of self and new in case of overflow.
Returns the junction at index i, or None if the location doesn’t contain that many elements.
Returns a mutable reference to the junction at index i, or None if the location doesn’t contain that many
elements.
👎 Deprecated: Please use iter().rev()
Please use iter().rev()
Returns a reference iterator over the junctions in reverse.
👎 Deprecated: Please use into_iter().rev()
Please use into_iter().rev()
Consumes self and returns an iterator over the junctions in reverse.
Ensures that self begins with prefix and that it has a single Junction item following.
If so, returns a reference to this Junction item.
Example
let mut m = X3(Parachain(2), PalletInstance(3), OnlyChild);
assert_eq!(m.match_and_split(&X2(Parachain(2), PalletInstance(3))), Some(&OnlyChild));
assert_eq!(m.match_and_split(&X1(Parachain(2))), None);Trait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more