Struct xcm::v2::prelude::opaque::MultiLocation [−][src]
A relative path between state-bearing consensus systems.
A location in a consensus system is defined as an isolatable state machine held within global consensus. The location in question need not have a sophisticated consensus algorithm of its own; a single account within Ethereum, for example, could be considered a location.
A very-much non-exhaustive list of types of location include:
- A (normal, layer-1) block chain, e.g. the Bitcoin mainnet or a parachain.
- A layer-0 super-chain, e.g. the Polkadot Relay chain.
- A layer-2 smart contract, e.g. an ERC-20 on Ethereum.
- A logical functional component of a chain, e.g. a single instance of a pallet on a Frame-based Substrate chain.
- An account.
A MultiLocation is a relative identifier, meaning that it can only be used to define the
relative path between two locations, and cannot generally be used to refer to a location
universally. It is comprised of an integer number of parents specifying the number of times to
“escape” upwards into the containing consensus system and then a number of junctions, each
diving down and specifying some interior portion of state (which may be considered a
“sub-consensus” system).
This specific MultiLocation implementation uses a Junctions datatype which is a Rust enum
in order to make pattern matching easier. There are occasions where it is important to ensure
that a value is strictly an interior location, in those cases, Junctions may be used.
The MultiLocation value of Null simply refers to the interpreting consensus system.
Fields
parents: u8The number of parent junctions at the beginning of this MultiLocation.
interior: JunctionsThe interior (i.e. non-parent) junctions that this MultiLocation contains.
Implementations
Creates a new MultiLocation with the given number of parents and interior junctions.
Consume self and return the equivalent VersionedMultiLocation value.
Creates a new MultiLocation with 0 parents and a Here interior.
The resulting MultiLocation can be interpreted as the “current consensus system”.
Creates a new MultiLocation which evaluates to the parent context.
Creates a new MultiLocation which evaluates to the grand parent context.
Creates a new MultiLocation with parents and an empty (Here) interior.
Whether the MultiLocation has no parents and has a Here interior.
Return a mutable reference to the interior field.
Returns the number of Parent junctions at the beginning of self.
Returns boolean indicating whether self contains only the specified amount of
parents and no interior junctions.
Returns the first interior junction, or None if the location is empty or contains only
parents.
Returns last junction, or None if the location is empty or contains only parents.
Splits off the first interior junction, returning the remaining suffix (first item in tuple)
and the first element (second item in tuple) or None if it was empty.
Splits off the last interior junction, returning the remaining prefix (first item in tuple)
and the last element (second item in tuple) or None if it was empty or if self only
contains parents.
Mutates self, suffixing its interior junctions with new. Returns Err with new in
case of overflow.
Mutates self, prefixing its interior junctions with new. Returns Err with new in
case of overflow.
Consumes self and returns a MultiLocation suffixed with new, or an Err with theoriginal value of
self in case of overflow.
Consumes self and returns a MultiLocation prefixed with new, or an Err with the original value of
self in case of overflow.
Returns the junction at index i, or None if the location is a parent or if the location
does not contain that many elements.
Returns a mutable reference to the junction at index i, or None if the location is a
parent or if it doesn’t contain that many elements.
Decrements the parent count by 1.
Removes the first interior junction from self, returning it
(or None if it was empty or if self contains only parents).
Removes the last element from interior, returning it (or None if it was empty or if
self only contains parents).
Ensures that self has the same number of parents as prefix, its junctions begins with
the junctions of prefix and that it has a single Junction item following.
If so, returns a reference to this Junction item.
Example
let mut m = MultiLocation::new(1, X2(PalletInstance(3), OnlyChild));
assert_eq!(
m.match_and_split(&MultiLocation::new(1, X1(PalletInstance(3)))),
Some(&OnlyChild),
);
assert_eq!(m.match_and_split(&MultiLocation::new(1, Here)), None);Mutate self so that it is suffixed with suffix.
Does not modify self and returns Err with suffix in case of overflow.
Example
let mut m = MultiLocation::new(1, X1(Parachain(21)));
assert_eq!(m.append_with(X1(PalletInstance(3))), Ok(()));
assert_eq!(m, MultiLocation::new(1, X2(Parachain(21), PalletInstance(3))));Mutate self so that it is prefixed with prefix.
Does not modify self and returns Err with prefix in case of overflow.
Example
let mut m = MultiLocation::new(2, X1(PalletInstance(3)));
assert_eq!(m.prepend_with(MultiLocation::new(1, X2(Parachain(21), OnlyChild))), Ok(()));
assert_eq!(m, MultiLocation::new(1, X1(PalletInstance(3))));Trait Implementations
Performs the conversion.
Performs the conversion.
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more